@@ -21,28 +21,32 @@ def glm(
     force_crs_match=True,
     return_model=False,
 ):
-    """Train a generalized linear model to predict polygon attributes based on the collection of pixel values they contain.
+    """Train a generalized linear model to predict polygon attributes
+    based on the collection of pixel values they contain.
 
     Parameters
     ----------
     source_df : geopandas.GeoDataFrame, required
-        geodataframe containing source original data to be represented by another geometry
+        geodataframe containing source original data to
+        be represented by another geometry
     target_df : geopandas.GeoDataFrame, required
-        geodataframe containing target boundaries that will be used to represent the source data
+        geodataframe containing target boundaries that
+        will be used to represent the source data
     raster : str, required (default="nlcd_2011")
         path to raster file that will be used to input data to the regression model.
-        i.e. a coefficients refer to the relationship between pixel counts and population counts.
-        Defaults to 2011 NLCD
+        i.e. a coefficients refer to the relationship between pixel
+        counts and population counts. Defaults to 2011 NLCD
     raster_codes : list, required (default =[21, 22, 23, 24, 41, 42, 52])
-        list of integers that represent different types of raster cells. If no formula is given,
-        the model will be fit from a linear combination of the logged count of each cell type
-        listed here. Defaults to [21, 22, 23, 24, 41, 42, 52] which
+        list of integers that represent different types of raster cells. If no formula
+        is given, the model will be fit from a linear combination of the logged count
+        of each cell type listed here. Defaults to [21, 22, 23, 24, 41, 42, 52] which
         are informative land type cells from the NLCD
     variable : str, required
         name of the variable (column) to be modeled from the `source_df`
     formula : str, optional
-        patsy-style model formula that specifies the model. Raster codes should be prefixed with
-        "Type_", e.g. `"n_total_pop ~ -1 + np.log1p(Type_21) + np.log1p(Type_22)`
+        patsy-style model formula that specifies the model. Raster codes should be
+        prefixed with "Type_", e.g.
+        `"n_total_pop ~ -1 + np.log1p(Type_21) + np.log1p(Type_22)`
     likelihood : str, {'poisson', 'gaussian', 'neg_binomial'} (default = "poisson")
         the likelihood function used in the model
     force_crs_match : bool
@@ -54,18 +58,16 @@ def glm(
     Returns
     --------
     interpolated : geopandas.GeoDataFrame
-        a new geopandas dataframe with boundaries from `target_df` and modeled attribute
-        data from the `source_df`. If `return_model` is true, the function will also return
-        the fitted regression model for further diagnostics
-
-
+        a new geopandas dataframe with boundaries from `target_df` and modeled
+        attribute data from the `source_df`. If `return_model` is true, the
+        function will also return the fitted regression model for further diagnostics
     """
     source_df = source_df.copy()
     target_df = target_df.copy()
     _check_presence_of_crs(source_df)
     liks = {"poisson": Poisson, "gaussian": Gaussian, "neg_binomial": NegativeBinomial}
 
-    if likelihood not in liks.keys():
+    if likelihood not in liks:
         raise ValueError(f"likelihood must one of {liks.keys()}")
 
     if not raster_codes:
